@@ -1,8 +1,3 @@
-# TODO: Add comment
-# 
-# Author: jeroen
-###############################################################################
-
 responseplot.do <- function(dates, surveyvec, aggregate, ...){
 	dates <- as.Date(dates);
 	if(missing(aggregate)){
@@ -31,29 +26,39 @@ responseplot.do <- function(dates, surveyvec, aggregate, ...){
 #' Create a responseplot
 #' @param campaign_urn id of the campaign
 #' @param aggregate optional number of days to aggregate over. Defaults to something smart.
+#' @param privacy_state either "shared" or "private" or "both"
 #' @param ... stuff to pass on to oh.survey_response.read
 #' @return a responseplot
 #' @import ggplot2
 #' @export
-responseplot <- function(campaign_urn, aggregate, ...){
-
-	#secret argument printurl for debugging
-	geturl(match.call(expand.dots=T))
+responseplot <- function(campaign_urn, aggregate, privacy_state="both", ...){
 	
-	#retrieve data
-	myData <- oh.survey_response.read(campaign_urn=campaign_urn, column_list="urn:ohmage:context:timestamp,urn:ohmage:survey:id", ...);
+	#printurl
+	geturl(match.call(expand.dots=T));
+	
+	#grab data
+	myData <- oh.survey_response.function.read(campaign_urn, ...);
 	if(nrow(myData) > 0) myData <- na.omit(myData);
-	
-	#empty plot
-	if(nrow(myData) == 0){
-		return(qplot(0,0,geom="text", label="request returned no data.", xlab="", ylab="Response Count"));
+
+	#filter shared.
+	if(privacy_state == "shared"){
+		myData <- myData[myData$privacy_state == "shared",];
+	} else if (privacy_state == "private"){
+		myData <- myData[myData$privacy_state == "private",];
 	}	
 	
-	#create plot:	
+	#check for no data
+	if(nrow(myData) == 0){
+		return(qplot(0,0,geom="text", label="request returned no data.", xlab="", ylab=""));
+	}	
+
+	#draw plot
 	plottitle <- paste("responseplot: ", gsub("urn:campaign:","",campaign_urn), sep="");
-	myplot <- responseplot.do(myData$context.timestamp, myData$survey.id, aggregate=aggregate, xlab="", ylab="Response Count", main=plottitle)
+	myplot <- responseplot.do(
+			rep(myData$date, myData$count), rep(myData$survey_id, myData$count),  
+			xlab="", ylab="Response Count", main=plottitle, aggregate, ...);
 	
 	#return
-	return(myplot);
+	return(myplot)	
 }
 
